@@ -1,4 +1,4 @@
-# $Id: Image.pm,v 1.10 2006/08/22 13:03:13 rousse Exp $
+# $Id: Image.pm,v 1.4 2004/03/31 13:53:52 guillaume Exp $
 package WWW::Google::Images::Image;
 
 =head1 NAME
@@ -15,16 +15,13 @@ Creates and returns a new C<WWW::Google::Images::Image> object.
 
 =cut
 
-use File::Basename;
-use File::Path;
-
 sub new {
     my ($class, $agent, $content, $context) = @_;
 
     my $self = bless {
-        _agent   => $agent,
-        _content => $content,
-        _context => $context,
+	_agent   => $agent,
+	_content => $content,
+	_context => $context,
     }, $class;
 
     return $self;
@@ -68,10 +65,6 @@ Optional parameters:
 
 Use $file as file name.
 
-=item dir => I<$directory>
-
-Use $directory as a directory path to save the file.  If only 'file' is specified, it will be saved in a path relative to the current working directory.
-
 =item base => I<$base>
 
 Use $base with lowercase original extension added as file name.
@@ -101,10 +94,6 @@ Optional parameters:
 
 Use $file as file name.
 
-=item dir => I<$directory>
-
-Use $directory as a directory path to save the file.  If only 'file' is specified, it will be saved in a path relative to the current working directory.
-
 =item base => I<$base>
 
 Use $base with lowercase original extension added as file name.
@@ -124,12 +113,6 @@ sub save_context {
 
 sub _save_as {
     my ($self, $file, $url) = @_;
-
-    # make sure the path exist
-    my $dir = dirname($file);
-    mkpath($dir) unless -d $dir;
-
-    # save file
     $self->{_agent}->get($url, ":content_file" => $file );
     $self->{_agent}->back();
 }
@@ -139,20 +122,20 @@ sub _get_file {
 
     my $file;
     if ($args{file}) {
-        $file = $args{file};
+	$file = $args{file};
     } elsif ($args{base}) {
-        $url =~ /(\.\w+)$/;
-        $file = $args{base} . lc($1);
+	$url =~ /(\.\w+)$/;
+	$file = $args{base} . lc($1);
     } else {
-        $url =~ /([^\/]+)$/;
-        $file = $1;
+	$url =~ /([^\/]+)$/;
+	$file = $1;
     }
 
     my $dir;
     if ($args{dir}) {
-        $dir = $args{dir};
+	$dir = $args{dir};
     } else {
-        $dir = '.';
+	$dir = '.';
     }
 
     return $dir . '/' . $file;
@@ -160,7 +143,7 @@ sub _get_file {
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004-2006, INRIA.
+Copyright (C) 2004, INRIA.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
